==> beast-privilege-api-3.0-GS-20250709.081401-2-sources.jar: com/thebeastshop/privilege/vo/LimitProductGroupVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class LimitProductGroupVO implements Serializable {
    private Integer id;
    private String productCodes;


    private Integer userGroupLimitNum;
    private Integer userLimitNum;
    private Integer totalLimitNum;

    private Integer currentBuyNum;

    private Date startTime;
    private Date endTime;
    private Integer channelType;
    private String accessWay;
    private String excludeStores;

    private String remark;
    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;
    private Integer active;

    private Integer prodStatus;


    private List<LimitProductVO> limitProductVOList;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getProductCodes() {
        return productCodes;
    }

    public void setProductCodes(String productCodes) {
        this.productCodes = productCodes;
    }


    public Integer getUserGroupLimitNum() {
        return userGroupLimitNum;
    }

    public void setUserGroupLimitNum(Integer userGroupLimitNum) {
        this.userGroupLimitNum = userGroupLimitNum;
    }

    public Integer getUserLimitNum() {
        return userLimitNum;
    }

    public void setUserLimitNum(Integer userLimitNum) {
        this.userLimitNum = userLimitNum;
    }

    public Integer getTotalLimitNum() {
        return totalLimitNum;
    }

    public void setTotalLimitNum(Integer totalLimitNum) {
        this.totalLimitNum = totalLimitNum;
    }

    public Integer getCurrentBuyNum() {
        return currentBuyNum;
    }

    public void setCurrentBuyNum(Integer currentBuyNum) {
        this.currentBuyNum = currentBuyNum;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public String getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(String accessWay) {
        this.accessWay = accessWay;
    }

    public String getExcludeStores() {
        return excludeStores;
    }

    public void setExcludeStores(String excludeStores) {
        this.excludeStores = excludeStores;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public Integer getProdStatus() {
        return prodStatus;
    }

    public void setProdStatus(Integer prodStatus) {
        this.prodStatus = prodStatus;
    }

    public List<LimitProductVO> getLimitProductVOList() {
        return limitProductVOList;
    }

    public void setLimitProductVOList(List<LimitProductVO> limitProductVOList) {
        this.limitProductVOList = limitProductVOList;
    }

}

==> beast-privilege-api-3.0.11-GS-20250905.063335-14-sources.jar: com/thebeastshop/privilege/vo/LimitProductGroupVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class LimitProductGroupVO implements Serializable {
    private Integer id;
    private String prodCodes;


    private Integer userGroupLimitNum;
    private Integer userLimitNum;
    private Integer totalLimitNum;

    private Integer currentBuyNum;

    private Date startTime;
    private Date endTime;
    private Integer channelType;
    private String accessWay;
    private String excludeStores;

    private String remark;
    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;
    private Integer active;

    private Integer prodStatus;


    private List<LimitProductVO> limitProductVOList;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getProdCodes() {
        return prodCodes;
    }

    public void setProdCodes(String prodCodes) {
        this.prodCodes = prodCodes;
    }


    public Integer getUserGroupLimitNum() {
        return userGroupLimitNum;
    }

    public void setUserGroupLimitNum(Integer userGroupLimitNum) {
        this.userGroupLimitNum = userGroupLimitNum;
    }

    public Integer getUserLimitNum() {
        return userLimitNum;
    }

    public void setUserLimitNum(Integer userLimitNum) {
        this.userLimitNum = userLimitNum;
    }

    public Integer getTotalLimitNum() {
        return totalLimitNum;
    }

    public void setTotalLimitNum(Integer totalLimitNum) {
        this.totalLimitNum = totalLimitNum;
    }

    public Integer getCurrentBuyNum() {
        return currentBuyNum;
    }

    public void setCurrentBuyNum(Integer currentBuyNum) {
        this.currentBuyNum = currentBuyNum;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public String getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(String accessWay) {
        this.accessWay = accessWay;
    }

    public String getExcludeStores() {
        return excludeStores;
    }

    public void setExcludeStores(String excludeStores) {
        this.excludeStores = excludeStores;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public Integer getProdStatus() {
        return prodStatus;
    }

    public void setProdStatus(Integer prodStatus) {
        this.prodStatus = prodStatus;
    }

    public List<LimitProductVO> getLimitProductVOList() {
        return limitProductVOList;
    }

    public void setLimitProductVOList(List<LimitProductVO> limitProductVOList) {
        this.limitProductVOList = limitProductVOList;
    }

}
